@@ -37,8 +37,10 @@ def run_example():
     # Define the mode here
     kwargs = {
         "mode": "cuboid",   # cuboid or cylinder
-        "version": "0.2.1",  # https://pypi.org/project/pyomniunwarp/
-        "calib_results_path": calib_results_path
+        "version": "0.2.4",  # https://pypi.org/project/pyomniunwarp/
+        "calib_results_path": calib_results_path,
+        "FOV": 90,
+        "output_height": 365
     }
 
     # Initialize the model, this would take some time
