@@ -174,7 +174,7 @@ class ScaramuzzaOcamModel():
 
         return mapx, mapy
 
-    def create_LUT_cuboid(self, FOV_angle=90):
+    def create_LUT_cuboid(self, FOV_angle=90, height=-1):
         '''
         Create Look Up Table (LUT) for remapping omnidirectional image into cuboid panorama image
 
@@ -187,7 +187,8 @@ class ScaramuzzaOcamModel():
         elevation_angle = self.get_ray_angle(self.Rmax)
         depression_angle = self.get_ray_angle(self.Rmin)
 
-        height = self.Rmax - self.Rmin
+        if height == -1:
+            height = self.Rmax - self.Rmin
 
         # R = distance from image plane to the optical center
         # R = h * tan(theta1) + h * tan(theta2)
@@ -409,6 +410,8 @@ class OmniUnwarp():
 
         self.mode = kwargs.get('mode', 'cuboid')
         self.version = kwargs.get('version', '0.2.2')
+        self.output_FOV = kwargs.get('FOV', 90)
+        self.output_height = kwargs.get('output_height', -1)
 
         if self.read_calib_results(kwargs.get('calib_results_path', '')):
             self.model = ScaramuzzaOcamModel(param=self.calib_results)
@@ -418,7 +421,8 @@ class OmniUnwarp():
 
         mask = self.create_mask()
         self.model.create_LUT_cylinder()
-        self.model.create_LUT_cuboid()
+        self.model.create_LUT_cuboid(
+            FOV_angle=self.output_FOV, height=self.output_height)
         self.model.mask_cylinder = self.model.cylinder_rectify(mask)
         self.model.mask_cuboid_plus = self.model.cuboid_rectify_plus(mask)
 
@@ -447,6 +451,10 @@ class OmniUnwarp():
         pixel = split_by_comma(lines[26])
         self.left_cropped_pixel, self.right_copped_pixel = int(
             pixel[0]), int(pixel[1])
+        self.width = int(self.calib_results['shape'][1] +
+                         self.left_cropped_pixel + self.right_copped_pixel)
+        self.height = int(self.calib_results['shape'][0])
+
         return True
 
     def crop_img(self, src):
